Ocyan plugin High availability
==============================
Installation
-------------
Add `ocyan.plugin.high_availability` to your projects dependencies.

Describe how to install the plugin. 


About & Usage of High availability
----------------------------------
Make oscar and wagtail work in a high availability setup with a master and slave database

If you want to enable the master and slave configuration of 2 database, make
sure to have the following settings:

1. The default database should the the WRITABLE database. You should just enter
   the ip address of the server the master database is one, for example:
   
   DATABASES["default"]["HOST"] = "192.168.1.3"
2. An additional database configurattion must be added that servers as the
   READONLY database, for example:
   
   DATABASES["read"] = DATABASES["default"]

Usually you only want to enable this stuff for production databases.
